@@ -5,7 +5,7 @@ use strict;
 
 use base 'Number::Object::Plugin::Tax';
 
-our $VERSION = 0.03_01;
+our $VERSION = 0.01;
 our $RATE    = 1.1;
 
 sub calc {
@@ -17,38 +17,13 @@ sub calc {
   return $total - $price;
 }
 
-sub deduct_tax : Method {
-  my ($self, $c) = @_;
-
-  my $price = $c->{value};
-  my $total = $price / $RATE;
-
-  return $total;
-}
-
-sub inc_price_tax_portion : Method {
-  my ($self, $c) = @_;
-
-  my $price = $c->{value};
-
-  return $price / 11;
-}
-
-sub ex_price_tax_portion : Method {
-  my ($self, $c) = @_;
-
-  my $price = $c->{value};
-
-  return $price / 10;
-}
-
 =head1 NAME
 
 Number::Object::Plugin::Tax::AU::GST - a Number::Object plugin for Australian GST
 
 =head1 VERSION
 
-Version 0.03_01
+Version 0.01
 
 =cut
 
